@@ -3,7 +3,7 @@ package App::BrowserUtils;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-06-13'; # DATE
 our $DIST = 'App-BrowserUtils'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -34,25 +34,41 @@ our %browsers = (
 
 our $sch_cmd = ['any*', of=>[ ['array*',of=>'str*',min_len=>1], ['str*'] ]];
 
-our %argsopt_browser_cmd = (
+our %argopt_firefox_cmd = (
     firefox_cmd => {
         schema => $sch_cmd,
         default => 'firefox',
     },
+);
+
+our %argopt_chrome_cmd = (
     chrome_cmd => {
         schema => $sch_cmd,
         default => 'google-chrome',
     },
+);
+
+our %argopt_opera_cmd = (
     opera_cmd => {
         schema => $sch_cmd,
         default => 'opera',
     },
+);
+
+our %argopt_vivaldi_cmd = (
     vivaldi_cmd => {
         schema => $sch_cmd,
         default => 'vivaldi',
     },
 );
 
+our %argsopt_browser_cmd = (
+    %argopt_firefox_cmd,
+    %argopt_chrome_cmd,
+    %argopt_opera_cmd,
+    %argopt_vivaldi_cmd,
+);
+
 our %argsopt_browser_start = (
     start_firefox => {
         schema => 'bool*',
@@ -537,7 +553,7 @@ App::BrowserUtils - Utilities related to browsers, particularly modern GUI ones
 
 =head1 VERSION
 
-This document describes version 0.007 of App::BrowserUtils (from Perl distribution App-BrowserUtils), released on 2020-06-13.
+This document describes version 0.008 of App::BrowserUtils (from Perl distribution App-BrowserUtils), released on 2020-06-13.
 
 =head1 SYNOPSIS
 
